#!/usr/sbin/dtrace -Zs
/*
 * typewriter.d - Turn the console keyboard into a noisy typewriter.
 *                Written in DTrace (Solaris 10 3/05).
 *
 * This is for Sun servers that have a console keyboard and an audio speaker,
 * for example - the Ultra 5. You may need to edit the ENTERKEY varable
 * below in the script to match your keyboard (see the end of the script for
 * help determining your enter key number), and you may need to edit the 
 * probe definitions to match your kbd driver. Check for scripts in this 
 * directory for specific hardware.
 *
 * 16-Sep-2005, ver 0.80
 *
 * USAGE:       typewriter.d &
 *
 * SEE ALSO:	/usr/dt/bin/sdtaudiocontrol	# to set volume
 *
 * Standard Disclaimer: This is freeware, use at your own risk.
 *
 * 08-Sep-2005  Brendan Gregg   Created this.
 */

#pragma D option quiet
#pragma D option destructive
#pragma D option switchrate=20hz

inline int ENTERKEY = 89;		/* Ultra 5/10 */
inline int COLUMNWARN = 72;		/* warning ping */

dtrace:::BEGIN
{
	trace("typewriter.d running for the console keyboard.\n");
	column = 0;
}

fbt:kb:kbdkeyreleased:entry,
fbt:kbtrans:kbtrans_untrans_keypressed_raw:entry
/arg1 != ENTERKEY/
{
	system("cat click.au > /dev/audio &");
	column++;
}

fbt:kb:kbdkeyreleased:entry,
fbt:kbtrans:kbtrans_untrans_keypressed_raw:entry
/arg1 != ENTERKEY && column == COLUMNWARN/
{
	system("cat clink.au > /dev/audio &");
}

fbt:kb:kbdkeyreleased:entry,
fbt:kbtrans:kbtrans_untrans_keypressed_raw:entry
/arg1 == ENTERKEY/
{
	system("cat return.au > /dev/audio &");
	column = 0;

	/*
	 * If the enter key isn't making the right sound, uncomment
	 * the following to learn what the ENTERKEY number should be.
	 */

	/* printf("number: %d\n", arg1) */
}
